-------------------------
SciPy-compatible Routines
-------------------------

The following pages describe SciPy-compatible routines.
These functions cover a subset of
`SciPy routines <https://docs.scipy.org/doc/scipy/reference/#api-reference>`_.


.. module:: cupyx.scipy

.. toctree::
   :maxdepth: 2

   scipy_fft
   fftpack
   ndimage
   sparse
   special
   signal
